#!/bin/zsh
#
# read console logs by connecting to a headnode
# 
# Andras.Horvath@cern.ch
#
# v0.1, 01/06/2006
# v0.2, 25/09/2009
# FIXME: after conserver migration is complete, remove most of the script:)

zmodload zsh/net/tcp

CLIENT="$1"
LOGDIR=/var/log/console
OLDLOGDIR=/var/log/console/oldlogs

if [[ -z "$CLIENT" ]] || [[ "-h" == "$CLIENT" ]]; then
	echo "Usage: $0 hostname [[old_log_no]]"
	echo "Where hostname is the machine whose logs are to be viewed,"
	echo "and old_log_no (optional) is 1,2,3,4... to display old logs"
	echo "(normally: last week, the week before, 3 weeks ago etc)".
	exit 1
fi

HEADNODE=${CLIENT}.headnode.cern.ch

OLDLOGNO=$2


# is this a 'conserver'-based server?
ztcp $HEADNODE 7782 2>/dev/null
fd=$REPLY
if [[ -n "$fd" ]]; then
	echo "This machine has its console on a 'conserver'-based console server."
	echo "Please use ^Ecp from the console to scroll back in logs, or see the"
	echo "users' guide: http://cern.ch/service-console/user_guide.html"
	ztcp -c $fd
	console -M $HEADNODE -p 7782 $CLIENT
	exit 0
fi

# was the current logfile or some logrotated older one requested?
if [[ -z "$OLDLOGNO" ]]; then
	LOGFILE=${LOGDIR}/${CLIENT}
else
	LOGFILE=${OLDLOGDIR}/${CLIENT}.${OLDLOGNO}.gz
fi

# we run 'less' on the headnode because this way we don't have to 
# read the whole file before actually displaying something. In most cases
# we hope to avoid having to read the whole file at all, as 'less' can
# (this way) optimize file seeks etc.
#
## 'less' also knows how to handle *.gz
# Actually it doesn't seem to be able to handle them when called like this
#  so we are doing the check for him
#
# 'ssh -t' forces the allocation of a pty even though we're a script
#	(so that less works :)
#
if [[ -z "$OLDLOGNO" ]]; then
	ssh -t $HEADNODE "less $LOGFILE"
else
	ssh -t $HEADNODE "zless $LOGFILE"
fi
